==> knative-model-4.12.0-sources.jar: io/fabric8/knative/sources/v1beta1/ContainerSourceBuilder.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ContainerSourceBuilder extends ContainerSourceFluentImpl<ContainerSourceBuilder> implements VisitableBuilder<ContainerSource,ContainerSourceBuilder> {

    ContainerSourceFluent<?> fluent;
    Boolean validationEnabled;

    public ContainerSourceBuilder() { 
        this(true);
    }


    public ContainerSourceBuilder(Boolean validationEnabled) { 
        this(new ContainerSource(), validationEnabled);
    }


    public ContainerSourceBuilder(ContainerSourceFluent<?> fluent) { 
        this(fluent, true);
    }


    public ContainerSourceBuilder(ContainerSourceFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new ContainerSource(), validationEnabled);
    }


    public ContainerSourceBuilder(ContainerSourceFluent<?> fluent,ContainerSource instance) { 
        this(fluent, instance, true);
    }


    public ContainerSourceBuilder(ContainerSourceFluent<?> fluent,ContainerSource instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public ContainerSourceBuilder(ContainerSource instance) { 
        this(instance,true);
    }


    public ContainerSourceBuilder(ContainerSource instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public ContainerSource build() {
        ContainerSource buildable = new ContainerSource(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ContainerSourceBuilder that = (ContainerSourceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.1.2-sources.jar: io/fabric8/knative/sources/v1beta1/ContainerSourceBuilder.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ContainerSourceBuilder extends ContainerSourceFluentImpl<ContainerSourceBuilder> implements VisitableBuilder<ContainerSource,ContainerSourceBuilder> {

    ContainerSourceFluent<?> fluent;
    Boolean validationEnabled;

    public ContainerSourceBuilder() {
        this(true);
    }

    public ContainerSourceBuilder(Boolean validationEnabled) {
        this(new ContainerSource(), validationEnabled);
    }

    public ContainerSourceBuilder(ContainerSourceFluent<?> fluent) {
        this(fluent, true);
    }

    public ContainerSourceBuilder(ContainerSourceFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ContainerSource(), validationEnabled);
    }

    public ContainerSourceBuilder(ContainerSourceFluent<?> fluent,ContainerSource instance) {
        this(fluent, instance, true);
    }

    public ContainerSourceBuilder(ContainerSourceFluent<?> fluent,ContainerSource instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public ContainerSourceBuilder(ContainerSource instance) {
        this(instance,true);
    }

    public ContainerSourceBuilder(ContainerSource instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.sources.v1beta1.EditableContainerSource build() {
        EditableContainerSource buildable = new EditableContainerSource(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ContainerSourceBuilder that = (ContainerSourceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
